@@ -1,14 +1,14 @@
 sample_p_helper = function(i, m, x_lower) {
   ## Total sample size
-  N = get_n(m)
+  n = get_n(m)
   ntail_prop = get_ntail(m, prop = TRUE)
 
   ## Proportion to sample
-  n1 = sum(runif(N) > ntail_prop) # less than xmin
+  n1 = sum(runif(n) > ntail_prop) # less than xmin
 
-  # q should be of length N
+  # q should be of length n
   c(sample(x_lower, n1, replace = TRUE), #less than xmin
-    dist_rand(m, N - n1))
+    dist_rand(m, n - n1))
 }
 
 bootstrap_p_helper = function(i, m, x_lower, xmins, pars, xmax, distance) {
@@ -42,9 +42,9 @@ get_bootstrap_p_sims = function(m, no_of_sims, seed, threads = 1) {
 
 #' @rdname estimate_xmin
 #' @export
-bootstrap_p = function(m, xmins=NULL, pars=NULL, xmax=1e5,
-                        no_of_sims=100, threads=1,
-                        seed=NULL, distance="ks") {
+bootstrap_p = function(m, xmins = NULL, pars = NULL, xmax = 1e5,
+                        no_of_sims = 100, threads = 1,
+                        seed = NULL, distance = "ks") {
 
   if (is.null(m$getPars())) {
     message("Parameters will be initially estimated via estimate_xmin")
@@ -81,7 +81,7 @@ bootstrap_p = function(m, xmins=NULL, pars=NULL, xmax=1e5,
   x = m_cpy$dat
   x_lower = x[x < m_cpy$xmin]
 
-  ## Start clock and parallel boostrap
+  ## Start clock and parallel bootstrap
   time$start()
   cl = makeCluster(threads)
   on.exit(stopCluster(cl))
