@@ -5,10 +5,10 @@
 #' A standard technique is to use Vuong's test.
 #' This is a likelihood ratio test for model selection using the
 #' Kullback-Leibler criteria.
-#' The test statistic, \code{R}, is the ratio of the
+#' The test statistic, `R`, is the ratio of the
 #' log-likelihoods of the data between the two competing models.
-#' The sign of \code{R} indicates which model is better.
-#' Since the value of \code{R} is esimated,
+#' The sign of `R` indicates which model is better.
+#' Since the value of `R` is esimated,
 #' we use the method proposed by Vuong, 1989 to select the model.
 #'
 #' This function compares two models.
@@ -24,20 +24,20 @@
 #'
 #' @return This function returns
 #' \describe{
-#' \item{\code{test_statistic}}{The test statistic.}
-#' \item{\code{p_one_sided}}{A one-sided p-value, which is an upper limit
+#' \item{`test_statistic`}{The test statistic.}
+#' \item{`p_one_sided`}{A one-sided p-value, which is an upper limit
 #' on getting that small a log-likelihood ratio if the
-#' first distribution, \code{d1}, is actually true.}
-#' \item{\code{p_two_sided}}{A two-sided p-value, which is the probability
+#' first distribution, `d1`, is actually true.}
+#' \item{`p_two_sided`}{A two-sided p-value, which is the probability
 #' of getting a log-likelihood ratio which deviates that much from zero
 #' in either direction, if the two distributions are actually equally good.}
-#' \item{\code{ratio}}{A data frame with two columns. The first column is
-#' the \code{x} value and second column is the difference in
+#' \item{`ratio`}{A data frame with two columns. The first column is
+#' the `x` value and second column is the difference in
 #' log-likelihoods.}}
 #' @param d1 A distribution object
 #' @param d2 A distribution object
 #' @note Code initially based on R code developed by
-#' Cosma Rohilla Shalizi (\url{http://bactra.org/}).
+#' Cosma Rohilla Shalizi (<http://bactra.org/>).
 #' Also see Appendix C in Clauset et al, 2009.
 #' @references Vuong, Quang H. (1989):
 #' "Likelihood Ratio Tests for Model Selection and Non-Nested Hypotheses",
@@ -74,13 +74,16 @@ compare_distributions = function(d1, d2) {
   if (!(inherits(d1, "discrete_distribution") == inherits(d2, "discrete_distribution")))
     stop("You seem to be comparing a discrete distribution with a continuous distribution")
 
-  xmin1 = d1$getXmin(); xmin2 = d2$getXmin()
+  xmin1 = d1$getXmin()
+  xmin2 = d2$getXmin()
   if (xmin1 != xmin2)
     stop("Lower threshold, xmin, should be the same in both models")
-  q = d1$getDat(); q = q[q >= d1$getXmin()]
+  q = d1$getDat()
+  q = q[q >= d1$getXmin()]
   ll_ratio_pts = dist_pdf(d1, q, log = TRUE) - dist_pdf(d2, q, log = TRUE)
 
-  m = mean(ll_ratio_pts); s = sd(ll_ratio_pts)
+  m = mean(ll_ratio_pts)
+  s = sd(ll_ratio_pts)
   v = sqrt(length(ll_ratio_pts)) * m / s
   p1 = pnorm(v)
 
