@@ -22,12 +22,11 @@ dplcon = function(x, xmin, alpha, log = FALSE) {
   pdf
 }
 
-
 #'@rdname dplcon
 #'@export
 #'@examples
 #' plot(x, pplcon(x, xmin, alpha), type="l", main="Distribution function")
-pplcon = function(q, xmin, alpha, lower.tail = TRUE) {
+pplcon = function(q, xmin, alpha, lower.tail = TRUE) { #nolint
   cdf = 1 - (q / xmin) ^ (-alpha + 1)
   if (!lower.tail)
     cdf = 1 - cdf
@@ -35,7 +34,6 @@ pplcon = function(q, xmin, alpha, lower.tail = TRUE) {
   cdf
 }
 
-
 #'@rdname dplcon
 #'@note The discrete random number generator is very inefficient
 #'@export
