@@ -2,7 +2,9 @@ test_that("Test plotting", {
   skip_on_cran()
   x = 1:4
   ##Discrete power-law
-  mt = displ$new(x); mt$setPars(3); mt$setXmin(2)
+  mt = displ$new(x)
+  mt$setPars(3)
+  mt$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(mt, draw = FALSE), d_exact, tol = 1e-4)
@@ -12,7 +14,9 @@ test_that("Test plotting", {
   expect_equal(d2$y, y, tol = 1e-4)
 
   ##Poisson
-  m = dispois$new(x); m$setPars(1); m$setXmin(2)
+  m = dispois$new(x)
+  m$setPars(1)
+  m$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(m, draw = FALSE), d_exact, tol = 1e-4)
@@ -22,7 +26,9 @@ test_that("Test plotting", {
   expect_equal(d2$y, y, tol = 1e-5)
 
   ##Discrete Log normal
-  m = dislnorm$new(x); m$setPars(c(1, 1)); m$setXmin(2)
+  m = dislnorm$new(x)
+  m$setPars(c(1, 1))
+  m$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(m, draw = FALSE), d_exact, tol = 1e-4)
@@ -32,7 +38,9 @@ test_that("Test plotting", {
   expect_equal(d2$y, y, tol = 1e-4)
 
   ##CTN power-law
-  m = conpl$new(x); m$setPars(3); m$setXmin(2)
+  m = conpl$new(x)
+  m$setPars(3)
+  m$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(m, draw = FALSE), d_exact, tol = 1e-4)
@@ -42,7 +50,9 @@ test_that("Test plotting", {
   expect_equal(d2$y, y, tol = 1e-4)
 
   ##Log normal
-  m = conlnorm$new(x); m$setPars(c(1, 1)); m$setXmin(2)
+  m = conlnorm$new(x)
+  m$setPars(c(1, 1))
+  m$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(m, draw = FALSE), d_exact, tol = 1e-4)
@@ -51,10 +61,10 @@ test_that("Test plotting", {
   y = c(0.7500, 0.6408, 0.5298, 0.4226)
   expect_equal(d2$y, y, tol = 1e-4)
 
-
-
   ##Exponential
-  m = conexp$new(x); m$setPars(0.5); m$setXmin(2)
+  m = conexp$new(x)
+  m$setPars(0.5)
+  m$setXmin(2)
 
   d_exact = data.frame(x = 1:4, y = 4:1 / 4)
   expect_equal(plot(m, draw = FALSE), d_exact, tol = 1e-4)
@@ -63,6 +73,5 @@ test_that("Test plotting", {
   y = c(0.7500, 0.5783, 0.4168, 0.2759)
   expect_equal(d2$y, y, tol = 1e-4)
 
-
 }
 )
